---
title: <span class="badge object-type-scalar"></span> RevolutionsPerMinute
---
# <span class="badge object-type-scalar"></span> RevolutionsPerMinute

Rotational Speed: Revolutions per minute (rpm)

## Definition

```python
# Rotational Speed: Revolutions per minute (rpm)
RevolutionsPerMinute: typing.Literal["rotrpm"] = "rotrpm"
```
